import { CryptoSession } from './session.js';
import { Schema } from './schema.js';
import { z } from 'zod';
export type Fetcher = (input: RequestInfo | URL, init?: RequestInit | undefined) => Promise<Response>;
export interface SecureInstance {
    fetch: SecureFetch;
    session: CryptoSession;
}
export interface SecureFetchOptions extends RequestInit {
    hostname?: string;
    fetcher?: Fetcher;
}
export interface SecureResponse extends Response {
    token?: string;
    data?: string | z.infer<typeof Schema.object>;
    err?: any;
}
export declare class SecureFetch extends Function {
    readonly session: CryptoSession;
    readonly hostname: string;
    readonly fetcher: Fetcher;
    options: RequestInit;
    static create(peerKey: string | Uint8Array, secretKey: string | Uint8Array, options?: SecureFetchOptions): SecureInstance;
    static generate(peerKey: string | Uint8Array, options?: SecureFetchOptions): SecureInstance;
    constructor(peerKey: string | Uint8Array, secretKey: string | Uint8Array, options?: SecureFetchOptions);
    fetch(path: RequestInfo | URL, options: SecureFetchOptions): Promise<SecureResponse>;
    get(path: string, opt: RequestInit): Promise<SecureResponse>;
    post(path: string, opt: RequestInit): Promise<SecureResponse>;
    handleResponse(res: SecureResponse): Promise<SecureResponse>;
}
//# sourceMappingURL=fetch.d.ts.map