import { Token } from './token.js';
import { Cipher, ECC, Signer } from '@cmdcode/crypto-utils';
export type Payload = string | object;
export interface EncodedData {
    data: string;
    token: Token;
}
export interface DecodedData {
    data: Payload;
    isValid: boolean;
}
export declare class CryptoSession {
    private readonly secret;
    peerKey: Uint8Array;
    static randomKeys(): ECC.KeyPair;
    static generate(peerKey: string | Uint8Array): CryptoSession;
    static withToken(b64token: string, secretKey: string | Uint8Array): CryptoSession;
    constructor(peerKey: string | Uint8Array, secretKey: string | Uint8Array);
    get peerHex(): string;
    get cipher(): Cipher;
    get signer(): Signer;
    get pubKey(): Uint8Array;
    get pubHex(): string;
    get sharedSecret(): Promise<Uint8Array>;
    get sharedHash(): Promise<Uint8Array>;
    get sharedHex(): Promise<string>;
    isWith(key: string): boolean;
    encrypt(data: Uint8Array): Promise<Uint8Array>;
    decrypt(data: Uint8Array): Promise<Uint8Array>;
    sign(payload: string | Uint8Array): Promise<Uint8Array>;
    verify(token: string | Token, payload: string | Uint8Array): Promise<boolean>;
    encode(payload: Payload): Promise<EncodedData>;
    decode(token: string | Token, payload: string): Promise<DecodedData>;
}
//# sourceMappingURL=session.d.ts.map